

use Egypt_breastfeed.dta, clear

/* For figures on breastfeeding gender differences by birth order */

#delimit ;
reg breastfeed_mths 
d_male_bord1-d_male_bord8 
d_bord2-d_bord8 d_agemonths* 
if child_twin == 0 & child_dead_age1 == 0, 
robust cluster(caseid_n);

/* regressions of breastfeeding gender differences by birth order */

#delimit ;
reg breastfeed_mths 
d_male bord bord_sqr 
d_agemonths1-d_agemonths60 
if child_dead_age1 == 0 & child_twin == 0, robust cluster(caseid_n) ;

#delimit ;
reg breastfeed_mths 
d_male bord bord_sqr 
current_age current_age_sqr d_educ1-d_educ5 
child_birth_year child_birth_year_sqr rural 
d_agemonths1-d_agemonths60 
if child_dead_age1 == 0 & child_twin == 0, robust cluster(caseid_n) ;

#delimit ;
reg breastfeed_mths 
d_male_bord d_male_bord_sqr 
bord bord_sqr 
current_age current_age_sqr d_educ1-d_educ5 
child_birth_year child_birth_year_sqr rural 
d_agemonths1-d_agemonths60 
if child_dead_age1 == 0 & child_twin == 0, robust cluster(caseid_n) ;


/* Ideal fertility regressions */

#delimit ;
reg breastfeed_mths 
d_male ideal_child_dist d_idealdist_pos 
d_agemonths1-d_agemonths60 
if child_dead_age1 == 0 & child_twin == 0, robust cluster(caseid_n) ;

#delimit ;
reg breastfeed_mths 
d_male ideal_child_dist d_idealdist_pos d_idealdist_dist 
d_agemonths1-d_agemonths60 
if child_dead_age1 == 0 & child_twin == 0, robust cluster(caseid_n) ;

#delimit ;
reg breastfeed_mths 
d_male ideal_child_dist d_idealdist_pos d_idealdist_dist 
current_age current_age_sqr d_educ1-d_educ5 
child_birth_year child_birth_year_sqr rural 
d_agemonths1-d_agemonths60 
if child_dead_age1 == 0 & child_twin == 0, robust cluster(caseid_n) ;

#delimit ;
reg breastfeed_mths 
d_male d_male_idealdist d_male_idealpos d_male_idealdist_dist 
ideal_child_dist d_idealdist_pos d_idealdist_dist 
current_age current_age_sqr d_educ1-d_educ5 
child_birth_year child_birth_year_sqr rural 
d_agemonths1-d_agemonths60 
if child_dead_age1 == 0 & child_twin == 0, robust cluster(caseid_n) ;


/* Previous sons regressions */

#delimit ;
reg breastfeed_mths 
d_male d_prevson bord 
current_age current_age_sqr d_educ1-d_educ5 
child_birth_year child_birth_year_sqr rural 
d_agemonths1-d_agemonths60 
if child_dead_age1 == 0 & child_twin == 0, robust cluster(caseid_n) ;

#delimit ;
reg breastfeed_mths 
d_male prevsons_frac bord 
current_age current_age_sqr d_educ1-d_educ5 
child_birth_year child_birth_year_sqr rural 
d_agemonths1-d_agemonths60 
if child_dead_age1 == 0 & child_twin == 0, robust cluster(caseid_n) ;

#delimit ;
reg breastfeed_mths 
d_male d_prevson d_prevson_male bord 
current_age current_age_sqr d_educ1-d_educ5 
child_birth_year child_birth_year_sqr rural 
d_agemonths1-d_agemonths60 
if child_dead_age1 == 0 & child_twin == 0, robust cluster(caseid_n) ;

#delimit ;
reg breastfeed_mths 
d_male prevsons_frac prevsons_frac_male bord 
current_age current_age_sqr d_educ1-d_educ5 
child_birth_year child_birth_year_sqr rural 
d_agemonths1-d_agemonths60 
if child_dead_age1 == 0 & child_twin == 0, robust cluster(caseid_n) ;


/* Distance to ideal sons */

#delimit ;
reg breastfeed_mths 
d_male ideal_sons_dist d_idealsons_pos d_idealsons_dist 
d_agemonths1-d_agemonths60 
if child_dead_age1 == 0 & child_twin == 0, robust cluster(caseid_n) ;

#delimit ;
reg breastfeed_mths 
d_male ideal_sons_dist d_idealsons_pos d_idealsons_dist 
current_age current_age_sqr d_educ1-d_educ5 
child_birth_year child_birth_year_sqr rural 
d_agemonths1-d_agemonths60 
if child_dead_age1 == 0 & child_twin == 0, robust cluster(caseid_n) ;

#delimit ;
reg breastfeed_mths 
d_male ideal_sons_dist d_idealsons_pos d_idealsons_dist 
ideal_child_dist d_idealdist_pos d_idealdist_dist 
d_agemonths1-d_agemonths60 
if child_dead_age1 == 0 & child_twin == 0, robust cluster(caseid_n) ;

#delimit ;
reg breastfeed_mths 
d_male ideal_sons_dist d_idealsons_pos d_idealsons_dist 
ideal_child_dist d_idealdist_pos d_idealdist_dist 
current_age current_age_sqr d_educ1-d_educ5 
child_birth_year child_birth_year_sqr rural 
d_agemonths1-d_agemonths60 
if child_dead_age1 == 0 & child_twin == 0, robust cluster(caseid_n) ;

* OTHER OUTCOMES *

#delimit ;
keep if breastfeed_mths != . ;

/* Presence of younger sibling based on gender, sibling gender, birth order variables */

#delimit ;
reg d_youngsib 
d_male bord bord_sqr 
current_age current_age_sqr d_educ1-d_educ5 
child_birth_year child_birth_year_sqr rural 
d_agemonths1-d_agemonths60 
if child_dead_age1 == 0 & child_twin == 0, robust cluster(caseid_n) ;

#delimit ;
reg d_youngsib 
d_male ideal_child_dist d_idealdist_pos d_idealdist_dist 
current_age current_age_sqr d_educ1-d_educ5 
child_birth_year child_birth_year_sqr rural 
d_agemonths1-d_agemonths60 
if child_dead_age1 == 0 & child_twin == 0, robust cluster(caseid_n) ;

#delimit ;
reg d_youngsib 
d_male d_prevson d_prevson_male bord 
current_age current_age_sqr d_educ1-d_educ5 
child_birth_year child_birth_year_sqr rural 
d_agemonths1-d_agemonths60 if child_dead_age1 == 0 & child_twin == 0, robust cluster(caseid_n) ;

/* vaccinations based on gender, sibling gender, birth order variables */

#delimit ;
reg vaccins 
d_male bord bord_sqr 
current_age current_age_sqr d_educ1-d_educ5 
child_birth_year child_birth_year_sqr rural 
d_agemonths1-d_agemonths60 if child_dead_age1 == 0 & child_twin == 0, robust cluster(caseid_n) ;

#delimit ;
reg vaccins 
d_male 
ideal_child_dist d_idealdist_pos d_idealdist_dist
current_age current_age_sqr d_educ1-d_educ5 
child_birth_year child_birth_year_sqr rural 
d_agemonths1-d_agemonths60 
if child_dead_age1 == 0 & child_twin == 0, robust cluster(caseid_n) ;

reg vaccins 
d_male d_prevson d_prevson_male bord 
bord bord_sqr current_age current_age_sqr d_educ1-d_educ5 
child_birth_year child_birth_year_sqr rural 
d_agemonths1-d_agemonths60 if child_dead_age1 == 0 & child_twin == 0, robust cluster(caseid_n) ;

#delimit cr

***************************************
*WEANING AGE 0-6 MONTHS*
***************************************

xi i.child_birth_year i.interview_month i.region
 
#delimit ;
dprobit d_wean
d_male
ideal_child_dist d_idealdist_pos d_idealdist_dist
current_age current_age_sqr d_educ1-d_educ5 
rural _I* 
d_agemonths1-d_agemonths60 
if child_dead_age1 == 0 & child_twin == 0
& interview_date - child_birth_date_cmc <= 6
, robust cluster(caseid_n) ;

#delimit ;
dprobit d_wean
d_male bord bord_sqr
current_age current_age_sqr d_educ1-d_educ5 
child_birth_year child_birth_year_sqr rural 
d_agemonths1-d_agemonths60 
if child_dead_age1 == 0 & child_twin == 0
& interview_date - child_birth_date_cmc <= 6
, robust cluster(caseid_n) ;

#delimit ;
dprobit d_wean
d_male
d_male_bord d_male_bord_sqr
bord bord_sqr
current_age current_age_sqr d_educ1-d_educ5 
rural _I*
d_agemonths1-d_agemonths60 
if child_dead_age1 == 0 & child_twin == 0
& interview_date - child_birth_date_cmc <= 6
, robust cluster(caseid_n) ;

#delimit ;
dprobit d_wean 
d_male d_prevson bord 
current_age current_age_sqr d_educ1-d_educ5 
rural _I*
d_agemonths1-d_agemonths60 
if child_dead_age1 == 0 & child_twin == 0
& interview_date - child_birth_date_cmc <= 6
, robust cluster(caseid_n) ;

#delimit ;
dprobit d_wean 
d_male prevsons_frac bord 
current_age current_age_sqr d_educ1-d_educ5 
rural _I*
d_agemonths1-d_agemonths60 
if child_dead_age1 == 0 & child_twin == 0
& interview_date - child_birth_date_cmc <= 6
, robust cluster(caseid_n) ;


***************************************
*VACCINATIONS AGE 0-12 MONTHS*
***************************************

#delimit ;
reg vaccins 
d_male 
ideal_child_dist d_idealdist_pos d_idealdist_dist
current_age current_age_sqr d_educ1-d_educ5 
child_birth_year child_birth_year_sqr rural 
d_agemonths1-d_agemonths60 
if child_dead_age1 == 0 & child_twin == 0
& interview_date - child_birth_date_cmc <= 12
, robust cluster(caseid_n) ;

#delimit ;
reg vaccins 
d_male bord bord_sqr
current_age current_age_sqr d_educ1-d_educ5 
child_birth_year child_birth_year_sqr rural 
d_agemonths1-d_agemonths60 
if child_dead_age1 == 0 & child_twin == 0
& interview_date - child_birth_date_cmc <= 12
, robust cluster(caseid_n) ;

#delimit ;
reg vaccins 
d_male_bord d_male_bord_sqr
bord bord_sqr
current_age current_age_sqr d_educ1-d_educ5 
child_birth_year child_birth_year_sqr rural 
d_agemonths1-d_agemonths60 
if child_dead_age1 == 0 & child_twin == 0
& interview_date - child_birth_date_cmc <= 12
, robust cluster(caseid_n) ;

#delimit ;
reg vaccins 
d_male d_prevson d_prevson_male bord 
current_age current_age_sqr d_educ1-d_educ5 
child_birth_year child_birth_year_sqr rural 
d_agemonths1-d_agemonths60 
if child_dead_age1 == 0 & child_twin == 0
& interview_date - child_birth_date_cmc <= 12
, robust cluster(caseid_n) ;

#delimit ;
reg vaccins 
d_male prevsons_frac prevsons_frac_male bord 
current_age current_age_sqr d_educ1-d_educ5 
child_birth_year child_birth_year_sqr rural 
d_agemonths1-d_agemonths60 
if child_dead_age1 == 0 & child_twin == 0
& interview_date - child_birth_date_cmc <= 12
, robust cluster(caseid_n) ;


**********************************************
*OTHER LIQUIDS/SOLID FOODS - AGE 0-6 MTHS*
**********************************************

#delimit cr

xi i.child_birth_year i.region i.interview_month

#delimit ;
dprobit d_solid7 
d_male
ideal_child_dist d_idealdist_pos d_idealdist_dist
current_age current_age_sqr d_educ1-d_educ5 
rural _I* 
d_agemonths1-d_agemonths60 
if child_twin == 0 
& interview_date - child_birth_date_cmc <= 6
, robust cluster(caseid_n) ;

#delimit ;
dprobit d_liq7
d_male
ideal_child_dist d_idealdist_pos d_idealdist_dist
current_age current_age_sqr d_educ1-d_educ5 
rural _I* 
d_agemonths1-d_agemonths60 
if child_twin == 0 
& interview_date - child_birth_date_cmc <= 6
, robust cluster(caseid_n) ;

#delimit ;
dprobit d_solid7 
d_male
bord bord_sqr 
current_age current_age_sqr d_educ1-d_educ5 
rural _I* 
d_agemonths1-d_agemonths60 
if child_twin == 0 
& interview_date - child_birth_date_cmc <= 6
, robust cluster(caseid_n) ;

#delimit ;
dprobit d_liq7
d_male
bord bord_sqr 
current_age current_age_sqr d_educ1-d_educ5 
rural _I* 
d_agemonths1-d_agemonths60 
if child_twin == 0 
& interview_date - child_birth_date_cmc <= 6
, robust cluster(caseid_n) ;

#delimit ;
dprobit d_solid7 
d_male
d_male_bord d_male_bord_sqr
bord bord_sqr 
current_age current_age_sqr d_educ1-d_educ5 
rural _I* 
d_agemonths1-d_agemonths60 
if child_twin == 0 
& interview_date - child_birth_date_cmc <= 6
, robust cluster(caseid_n) ;

#delimit ;
dprobit d_liq7
d_male d_male_bord d_male_bord_sqr
bord bord_sqr 
current_age current_age_sqr d_educ1-d_educ5 
rural _I* 
d_agemonths1-d_agemonths60 
if child_twin == 0 
& interview_date - child_birth_date_cmc <= 6
, robust cluster(caseid_n) ;

#delimit ;
dprobit d_solid7 
d_male
d_prevson d_prevson_male bord
current_age current_age_sqr d_educ1-d_educ5 
rural _I* 
d_agemonths1-d_agemonths60 
if child_twin == 0 
& interview_date - child_birth_date_cmc <= 6
, robust cluster(caseid_n) ;

#delimit ;
dprobit d_liq7
d_male
d_prevson d_prevson_male bord
current_age current_age_sqr d_educ1-d_educ5 
rural _I* 
d_agemonths1-d_agemonths60 
if child_twin == 0 
& interview_date - child_birth_date_cmc <= 6
, robust cluster(caseid_n) ;

#delimit ;
dprobit d_solid7 
d_male
prevsons_frac prevsons_frac_male bord
current_age current_age_sqr d_educ1-d_educ5 
rural _I* 
d_agemonths1-d_agemonths60 
if child_twin == 0 
& interview_date - child_birth_date_cmc <= 6
, robust cluster(caseid_n) ;

#delimit ;
dprobit d_liq7
d_male
prevsons_frac prevsons_frac_male bord
current_age current_age_sqr d_educ1-d_educ5 
rural _I* 
d_agemonths1-d_agemonths60 
if child_twin == 0 
& interview_date - child_birth_date_cmc <= 6
, robust cluster(caseid_n) ;

#delimit cr


**********************************************
*DIARRHEA IN PAST 2 WEEKS - AGE 0-36 MTHS*
**********************************************

#delimit ;
dprobit d_diar 
d_male
ideal_child_dist d_idealdist_pos d_idealdist_dist
current_age current_age_sqr d_educ1-d_educ5 
rural _I* 
d_agemonths1-d_agemonths60 
if child_twin == 0 
& interview_date - child_birth_date_cmc <= 36
, robust cluster(caseid_n) ;

#delimit ;
dprobit d_diar 
d_male
bord bord_sqr 
current_age current_age_sqr d_educ1-d_educ5 
rural _I* 
d_agemonths1-d_agemonths60 
if child_twin == 0 
& interview_date - child_birth_date_cmc <= 36
, robust cluster(caseid_n) ;

#delimit ;
dprobit d_diar 
d_male
d_prevson d_prevson_male bord
current_age current_age_sqr d_educ1-d_educ5 
rural _I* 
d_agemonths1-d_agemonths60 
if child_twin == 0 
& interview_date - child_birth_date_cmc <= 36
, robust cluster(caseid_n) ;

#delimit ;
dprobit d_diar 
d_male
prevsons_frac prevsons_frac_male bord
current_age current_age_sqr d_educ1-d_educ5 
rural _I* 
d_agemonths1-d_agemonths60 
if child_twin == 0 
& interview_date - child_birth_date_cmc <= 36
, robust cluster(caseid_n) ;

#delimit cr
